<?php

namespace Core\Env;

use Dotenv\Dotenv;

class Env
{
    private static Dotenv $dotenv;

    /**
     * Load env
     *
     * @return void
     */
    public static function load(): void
    {
        $dotenv = Dotenv::createImmutable('../');
        $dotenv->load();

        self::$dotenv = $dotenv;
    }

    /**
     * Get key value
     *
     * @param string $key
     * @return mixed
     */
    public static function get(string $key): mixed
    {
        // Parse key
        $key = strtoupper($key);

        // Check if key exists
        if (!self::$dotenv->ifPresent($key)) {
            return false;
        }

        // Get value
        $result = $_ENV[$key];

        // Parse booleans
        try {
            if(self::$dotenv->required($key)->isBoolean()) {
                return filter_var($result, FILTER_VALIDATE_BOOLEAN);
            }
        } catch (\Exception) {
            // do nothing
        }

        // Parse integers
        try {
            if(self::$dotenv->required($key)->isInteger()) {
                return (int) $result;
            }
        } catch (\Exception) {
            // do nothing
        }

        return $result;
    }
}